@@ -1,5 +1,5 @@
 /*************************************************************************
-* COPYRIGHT (C) 1999 - 2003  EDF R&D
+* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
 * THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 * IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
 * AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
@@ -23,6 +23,11 @@
 med_err 
 MEDfermer(med_idt fid)
 {
+
+#ifdef _DEBUG_
+   _MEDobjetsOuverts(fid);
+#endif
+
   /*
    * On inhibe le gestionnaire d'erreur
    */
