@@ -1,5 +1,5 @@
 /*************************************************************************
-* COPYRIGHT (C) 1999 - 2003  EDF R&D
+* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
 * THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 * IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
 * AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
@@ -33,7 +33,7 @@ MEDnGauss(med_idt fid)
   else
     if (datagroup) if ( _MEDdatagroupFermer(datagroup) < 0) {
       MESSAGE("Impossible de fermer le datagroup : ");
-      ISCRUTE(datagroup); return -1; 
+      ISCRUTE_int(datagroup); return -1; 
     }
   
   if ( _MEDnObjets(fid,MED_GAUSS,&n) < 0 ) return -1;
