@@ -14,7 +14,7 @@ med_int MEDnLien   (_IN med_idt fid ) {
   else
     if (datagroup) if ( _MEDdatagroupFermer(datagroup) < 0) {
       MESSAGE("Impossible de fermer le datagroup : ");
-      ISCRUTE(datagroup); return -1; 
+      ISCRUTE_int(datagroup); return -1; 
     }
   
   if (  _MEDnObjets(fid,MED_LIENS,&n) < 0 ) return -1;
