@@ -1,5 +1,5 @@
 /*************************************************************************
-* COPYRIGHT (C) 1999 - 2003  EDF R&D
+* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
 * THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 * IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
 * AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
@@ -34,9 +34,33 @@ med_idt
 _MEDdatagroupCreer(med_idt pid, char *nom)
 {
   med_idt id;
+  med_err ret=0;
+  med_mode_acces MED_MODE_ACCES;
 
-  if ((id = H5Gcreate(pid,nom,0)) < 0)
+  if ( (MED_MODE_ACCES = _MEDmodeAcces(pid) ) == MED_UNDEF_MODE_ACCES ) {
+    MESSAGE("Impossible de dterminer le mode d'acces au fichier.");
     return -1;
+  }
+
+  if ( MED_MODE_ACCES == MED_LECTURE) {
+    MESSAGE("Impossible de crer un datagroup en mode MED_LECTURE.");
+    return -1;
+  };
+
+
+  id = _MEDdatagroupOuvrir(pid,nom);
+  if (id > 0)
+    if (MED_MODE_ACCES == MED_LECTURE_AJOUT) {
+      MESSAGE("Cration d'un datagroup existant impossible en mode MED_LECTURE_AJOUT.");
+      return -1;
+    };
+  /* sinon on le cre */
+  if (id <= 0)
+    if ((id = H5Gcreate(pid,nom,0)) < 0) {
+      MESSAGE("Impossible de crer le datagroup : ");
+      SSCRUTE(nom);
+      return -1;
+    }
 
   return id;
 }
