@@ -1,5 +1,5 @@
 /*************************************************************************
-* COPYRIGHT (C) 1999 - 2003  EDF R&D
+* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
 * THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 * IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
 * AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
@@ -32,10 +32,7 @@
 med_err 
 _MEDdatagroupFermer(med_idt id)
 {
-  med_err ret;
 
-  if ((ret = H5Gclose(id)) < 0)
-    return -1;
-  else
-    return 0;
+  if ( H5Gclose(id) < 0) return -1;
+  return 0;
 }
