@@ -1,5 +1,5 @@
 /*************************************************************************
-* COPYRIGHT (C) 1999 - 2003  EDF R&D
+* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
 * THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 * IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
 * AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
@@ -37,7 +37,10 @@ _MEDdatagroupLienCreer(med_idt id,const char *nom, const char *nom_lien)
 {
   med_err ret;
 
-  ret = H5Glink(id,H5G_LINK_SOFT,nom,nom_lien);
-   
+  if( (ret = H5Glink(id,H5G_LINK_SOFT,nom,nom_lien)) < 0 ) {
+    MESSAGE("Impossible de crer le lien : ");
+    SSCRUTE(nom_lien);
+  }
+  
   return ret;
 }
