@@ -1,13 +1,17 @@
+#!/bin/sh
+
 file=test30
-./${file} > /dev/null 2>&1 > ${file}.dump  && ( \
+${EXECDIR}/${file} > /dev/null 2>&1 > ${BUILDDIR}/${file}.dump  && ( \
 sed -e 's/DATATYPE  H5T_STD_I32BE//g' -e 's/DATATYPE  H5T_STD_I32LE//g'	 \
     -e 's/DATATYPE  H5T_STD_I64BE//g' -e 's/DATATYPE  H5T_STD_I64LE//g'  \
     -e 's/DATATYPE  H5T_IEEE_F64BE//g' -e 's/DATATYPE  H5T_IEEE_F64LE//g'  \
-	${file}.dump > ${file}.dump.tmp && \
+    -e 's/HDF5.*{//g' \
+	${BUILDDIR}/${file}.dump > ${BUILDDIR}/${file}.dump.tmp && \
 sed -e 's/DATATYPE  H5T_STD_I32BE//g' -e 's/DATATYPE  H5T_STD_I32LE//g'	 \
     -e 's/DATATYPE  H5T_STD_I64BE//g' -e 's/DATATYPE  H5T_STD_I64LE//g'  \
     -e 's/DATATYPE  H5T_IEEE_F64BE//g' -e 's/DATATYPE  H5T_IEEE_F64LE//g'  \
-	 ${SRCDIR}/dumps.ref/${file}.dump > ${file}.dump.ref && \
-diff ${file}.dump.ref ${file}.dump.tmp && \
-rm -f ${file}.dump.tmp && rm -f ${file}.dump.ref )
+    -e 's/HDF5.*{//g' \
+	 ${SRCDIR}/dumps.ref/${file}.dump > ${BUILDDIR}/${file}.dump.ref && \
+diff ${BUILDDIR}/${file}.dump.ref ${BUILDDIR}/${file}.dump.tmp && \
+rm -f ${BUILDDIR}/${file}.dump.tmp && rm -f ${BUILDDIR}/${file}.dump.ref )
 
